<?php
/*
This file checks and notifies you if your MOJO theme has an update. 
In the future it may perform the upgrade.
*/

function mm_check_mojo_theme() {
	if( is_admin() ) {
		delete_transient( 'mm_theme_notice' );
		$theme_root = get_theme_root();
		$files_array = glob( $theme_root . "/*" );
		$mojo_themes = get_option( 'mm_themes', array() );
		foreach ( $files_array as $theme ) {
			if( is_dir( $theme ) && file_exists( $theme . "/MOJOV.txt" ) ) {
				$mojo_themes[ md5( $theme ) ] = $theme;
			}
		}
		update_option( 'mm_themes', $mojo_themes );
		if( ! empty( $mojo_themes ) ) {
			mm_check_theme_version( $mojo_themes );
		}
	}
}
add_action( 'admin_head', 'mm_check_mojo_theme' );
add_action( 'wp_login', 'mm_check_mojo_theme' );

function mm_check_theme_version( $themes ) {
	foreach( $themes as $theme ) {
		$installed_theme_version = file_get_contents( $theme . "/MOJOV.txt" );
		$api_args = array(
			'mojo-platform' 	=> esc_attr( $installed_theme_version ),
			'mojo-type' 		=> '',
			'mojo-items' 		=> 'details'
		);
		$current_theme_data = mm_api( $api_args );
		$current_theme_data = json_decode( $current_theme_data['body'] );
		if( count( $current_theme_data )  > 0 ) {
			$current_theme_version = $current_theme_data->item_1->item_version_id;
			if( $installed_theme_version != $current_theme_version ) {
				$themes_w_updates = get_transient( 'mm_theme_notice' );
				$themes_w_updates[  md5( $current_theme_data->item_1->name ) ] = $current_theme_data->item_1->name;
				set_transient( 'mm_theme_notice', $themes_w_updates, DAY_IN_SECONDS );
			}
		}
	}
}

function mm_notify_theme_update() {
	if( $themes = get_transient( 'mm_theme_notice' ) ) {
		foreach ( $themes as $theme ) {
		?>
		<div class="error">
			<p>It looks like <a target='_blank' href='https://mojomarketplace.com/account/purchases'><?php echo $theme; ?></a> has been updated. Please go to your <a target='_blank' href='https://mojomarketplace.com/account/purchases'>MOJO account</a> to download.</p>
		</div>
		<?php
		}
	}
}
add_action( 'admin_notices', 'mm_notify_theme_update' );
